@@ -12,7 +12,7 @@
 //
 //    You should have received a copy of the GNU General Public License
 //    along with this program; if not, write to the Free Software
-//    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+//    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 
 #ifndef MOVIEDECODER_H
 #define MOVIEDECODER_H
@@ -34,7 +34,7 @@ namespace ffmpegthumbnailer
 class MovieDecoder
 {
 public:
-    MovieDecoder(const QString& filename, AVFormatContext* pavContext = NULL);
+    explicit MovieDecoder(const QString& filename, AVFormatContext* pavContext = NULL);
     ~MovieDecoder();
 
     QString getCodec();
